Index: /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/browser.txt
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/browser.txt	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/browser.txt	(revision 6470)
@@ -306,5 +306,5 @@
     ...                             sorted(os.listdir(ac_storage))[-2])
     >>> print open(archive_file, 'rb').read()
-    "prefix","serial","ac","status","history"
+    "prefix","serial","ac","state","history"
     "BLA","19.12","1","3"
     "BLA","0","BLA-1-<10-DIGITS>","initialized","..."
Index: /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/browser_templates/searchpage.pt
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/browser_templates/searchpage.pt	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/browser_templates/searchpage.pt	(revision 6470)
@@ -25,5 +25,5 @@
     	<tr>
     	  <th>&nbsp;</th>
-    	  <th width="50px">Serial</th><th>AC</th><th>Status</th><th>History</th>
+    	  <th width="50px">Serial</th><th>AC</th><th>State</th><th>History</th>
     	</tr>
       </thead>
@@ -34,5 +34,5 @@
     	  <td tal:content="item/batch_serial">1</td>
     	  <td tal:content="item/code">APP-1-1234567890</td>
-    	  <td tal:content="item/status">unused</td>
+    	  <td tal:content="item/state">unused</td>
           <td tal:content="structure python:item.history.replace('||','<br />')">
             history
Index: /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/catalog.py
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/catalog.py	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/catalog.py	(revision 6470)
@@ -18,5 +18,5 @@
     history = grok.index.Text(attribute='history')
     batch_serial = grok.index.Field(attribute='batch_serial')
-    status = grok.index.Field(attribute='status')
+    state = grok.index.Field(attribute='state')
 
 class AccessCodeQueryResultItem(object):
@@ -28,5 +28,5 @@
         self.code = context.representation
         self.history = context.history
-        self.status = context.status
+        self.state = context.state
         self.batch_serial = context.batch_serial
 
Index: /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/interfaces.py
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/interfaces.py	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/interfaces.py	(revision 6470)
@@ -24,6 +24,6 @@
         default = 0.0, min = 0.0,
         )
-    status = schema.TextLine(
-        title = u'Workflow status',
+    state = schema.TextLine(
+        title = u'Workflow state',
         )
     representation = schema.TextLine(
Index: /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/tests/test_accesscodes.py
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/tests/test_accesscodes.py	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/tests/test_accesscodes.py	(revision 6470)
@@ -106,21 +106,21 @@
 
     def test_invalidate_accesscode(self):
-        assert self.ac1.status != USED
+        assert self.ac1.state != USED
         result = invalidate_accesscode('APP-1-11111111')
-        assert self.ac1.status == USED
+        assert self.ac1.state == USED
         assert result is True
 
     def test_disable_accesscode_unused(self):
         # we can disable initialized acs
-        assert self.ac1.status != USED
+        assert self.ac1.state != USED
         disable_accesscode('APP-1-11111111')
-        assert self.ac1.status == DISABLED
+        assert self.ac1.state == DISABLED
 
     def test_disable_accesscode_used(self):
         # we can disable already used acs
-        assert self.ac1.status != DISABLED
+        assert self.ac1.state != DISABLED
         invalidate_accesscode('APP-1-11111111')
         disable_accesscode('APP-1-11111111')
-        assert self.ac1.status == DISABLED
+        assert self.ac1.state == DISABLED
 
     def test_reenable_accesscode(self):
@@ -129,5 +129,5 @@
         result = reenable_accesscode('APP-1-11111111')
         assert result is True
-        assert self.ac1.status != USED
+        assert self.ac1.state != USED
 
     def test_fire_transition(self):
Index: /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/tests/test_catalog.py
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/tests/test_catalog.py	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/tests/test_catalog.py	(revision 6470)
@@ -110,6 +110,6 @@
         # Now we want to find the disabled access code
         cat = queryUtility(ICatalog, name='accesscodes_catalog')
-        results1 = cat.searchResults(status=('disabled', 'disabled'))
-        results2 = cat.searchResults(status=('initialized', 'initialized'))
+        results1 = cat.searchResults(state=('disabled', 'disabled'))
+        results2 = cat.searchResults(state=('initialized', 'initialized'))
         results1 = [x for x in results1] # Turn results generator into list
         # We found 1 accescode disabled
@@ -125,6 +125,6 @@
         # Now we want to find the invalidated access code
         cat = queryUtility(ICatalog, name='accesscodes_catalog')
-        results1 = cat.searchResults(status=('used', 'used'))
-        results2 = cat.searchResults(status=('initialized', 'initialized'))
+        results1 = cat.searchResults(state=('used', 'used'))
+        results2 = cat.searchResults(state=('initialized', 'initialized'))
         results1 = [x for x in results1] # Turn results generator into list
         # We found 1 accescode used
@@ -145,5 +145,5 @@
         # exactly one access code.
         results = cat.searchResults(history='Tester',
-                                    status=('used', 'used'),
+                                    state=('used', 'used'),
                                     code=('APP-1-11111111', 'APP-1-22222222'))
         assert len(results) == 1
@@ -154,7 +154,7 @@
         # immediately in catalog
         cat = queryUtility(ICatalog, name='accesscodes_catalog')
-        result = cat.searchResults(status=('used', 'used'))
+        result = cat.searchResults(state=('used', 'used'))
         assert len(result) == 0
         invalidate_accesscode('APP-1-11111111')
-        result = cat.searchResults(status=('used', 'used'))
+        result = cat.searchResults(state=('used', 'used'))
         assert len(result) == 1
Index: /main/waeup.sirp/trunk/src/waeup/sirp/applicants/authentication.py
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/applicants/authentication.py	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/applicants/authentication.py	(revision 6470)
@@ -228,7 +228,7 @@
         if ac is None:
             return None
-        if ac.status == 'disabled':
-            return None
-        if ac.status == 'used' and appl_ac != ac.representation:
+        if ac.state == 'disabled':
+            return None
+        if ac.state == 'used' and appl_ac != ac.representation:
             return None
         if appl_ac is not None and appl_ac != ac.representation:
Index: /main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser.py
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser.py	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser.py	(revision 6470)
@@ -426,5 +426,5 @@
 
         # Mark pin as used (this also fires a pin related transition)
-        if get_access_code(pin).status == USED:
+        if get_access_code(pin).state == USED:
             pass
         else:
Index: /main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser_templates/applicantscontainermanagepage.pt
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser_templates/applicantscontainermanagepage.pt	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser_templates/applicantscontainermanagepage.pt	(revision 6470)
@@ -65,5 +65,5 @@
             <th>ID
             </th>
-            <th>status
+            <th>state
             </th>
           </tr>
Index: /main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_authentication.py
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_authentication.py	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_authentication.py	(revision 6470)
@@ -50,7 +50,7 @@
 
 class FakeAccessCode(object):
-    def __init__(self, repr, status = 'initialized'):
+    def __init__(self, repr, state = 'initialized'):
         self.representation = repr
-        self.status = status
+        self.state = state
 
 class FakeApplication(object):

Index: /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/accesscodes.py
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/accesscodes.py	(revision 6469)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/accesscodes/accesscodes.py	(revision 6470)
@@ -52,5 +52,5 @@
 
     @property
-    def status(self):
+    def state(self):
         return IWorkflowState(self).getState()
 
@@ -166,5 +166,5 @@
             )
         writer = csv.writer(open(csv_path, 'w'), quoting=csv.QUOTE_ALL)
-        writer.writerow(['prefix', 'serial', 'ac', 'status', 'history'])
+        writer.writerow(['prefix', 'serial', 'ac', 'state', 'history'])
         writer.writerow([self.prefix, '%0.2f' % self.cost, str(self.num),
                          str(self.entry_num)])
@@ -175,5 +175,5 @@
             writer.writerow([
                     self.prefix, value.batch_serial, value.representation,
-                    value.status, value.history
+                    value.state, value.history
                     ])
         return os.path.basename(csv_path)
@@ -251,5 +251,5 @@
 
     # This is temporary reimport solution. Access codes will be imported
     # with status initialized no matter if they have been used before.
     def reimport(self, filename, creator=u'UNKNOWN'):
         """Reimport a batch given in CSV file.
@@ -251,5 +251,5 @@
 
     # This is temporary reimport solution. Access codes will be imported
-    # with status initialized no matter if they have been used before.
+    # with state initialized no matter if they have been used before.
     def reimport(self, filename, creator=u'UNKNOWN'):
         """Reimport a batch given in CSV file.